@@ -895,9 +895,21 @@ g_content_type_guess (const char   *filename,
   
   if (filename)
     {
-      basename = g_path_get_basename (filename);
-      n_name_mimetypes = xdg_mime_get_mime_types_from_file_name (basename, name_mimetypes, 10);
-      g_free (basename);
+      i = strlen (filename);
+      if (filename[i - 1] == '/')
+        {
+          name_mimetypes[0] = "inode/directory";
+          name_mimetypes[1] = NULL;
+          n_name_mimetypes = 1;
+          if (result_uncertain)
+            *result_uncertain = TRUE;
+        }
+      else
+        {
+          basename = g_path_get_basename (filename);
+          n_name_mimetypes = xdg_mime_get_mime_types_from_file_name (basename, name_mimetypes, 10);
+          g_free (basename);
+        }
     }
 
   /* Got an extension match, and no conflicts. This is it. */
