@@ -26,7 +26,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "xdgmime.h"
@@ -104,8 +104,11 @@ xdg_dir_time_list_add (char   *file_name,
 
   for (list = dir_time_list; list; list = list->next) 
     {
-      if (strcmp (list->directory_name, file_name) == 0) 
-        return;
+      if (strcmp (list->directory_name, file_name) == 0)
+        {
+          free (file_name);
+          return;
+        }
     }
   
   list = calloc (1, sizeof (XdgDirTimeList));
@@ -627,6 +630,18 @@ xdg_mime_shutdown (void)
       _xdg_mime_parent_list_free (parent_list);
       parent_list = NULL;
     }
+
+  if (icon_list)
+    {
+      _xdg_mime_icon_list_free (icon_list);
+      icon_list = NULL;
+    }
+
+  if (generic_icon_list)
+    {
+      _xdg_mime_icon_list_free (generic_icon_list);
+      generic_icon_list = NULL;
+    }
   
   if (_caches)
     {
